#
# spec file for package libpeas
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with lua51
%bcond_without python3
Name:           libpeas
Version:        1.36.0
Release:        2.3
Summary:        GObject-based Plugin Engine
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://wiki.gnome.org/Projects/Libpeas
Source0:        https://download.gnome.org/sources/libpeas/1.36/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gladeui-2.0)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.39.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.0.0
%if %{with python3}
BuildRequires:  pkgconfig(python3) >= 3.2.0
%endif
%if %{with lua51}
BuildRequires:  lua51-devel >= 5.1.0
BuildRequires:  pkgconfig(luajit) >= 2.0
%endif

%description
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

%package -n libpeas-1_0-0
Summary:        GObject-based Plugin Engine
# We provide %%{name} to make the lang package installable
Group:          System/Libraries
Recommends:     %{name}-loader-python3
Provides:       %{name} = %{version}
# The gjs loader is officially no longer supported upstream (removed from git).
# With gjs moving to mozjs-24, it also fails building; so we follow upstream.
Obsoletes:      %{name}-loader-gjs <= %{version}
# Stop packaging the demo sub-package
Obsoletes:      %{name}-demo <= %{version}

%description -n libpeas-1_0-0
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

%package -n typelib-1_0-Peas-1_0
Summary:        Introspection bindings for libpeas, a GObject-based plugin engine
Group:          System/Libraries

%description -n typelib-1_0-Peas-1_0
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

This package provides the GObject Introspection bindings for the libpeas
library.

%package -n libpeas-gtk-1_0-0
Summary:        GObject-based Plugin Engine
Group:          System/Libraries

%description -n libpeas-gtk-1_0-0
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

%package -n typelib-1_0-PeasGtk-1_0
Summary:        Introspection bindings for the libpeas-gtk library
Group:          System/Libraries

%description -n typelib-1_0-PeasGtk-1_0
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

This package provides the GObject Introspection bindings for the
libpeas-gtk library.

%package loader-python3
Summary:        Python3 runtime loader for libpeas
Group:          System/Libraries
Supplements:    (libpeas-1_0-0 and python3)

%description loader-python3
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

This package contains the python3 loader.

%if %{with lua51}
%package loader-lua51
Summary:        Lua 5.1 runtime loader for libpeas
Group:          System/Libraries
Supplements:    packageand(libpeas-1_0-0:lua51)

%description loader-lua51
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

This package contains the LUA 5.1 loader.
%endif

%package -n glade-catalog-libpeas
Summary:        Glade catalog for libpeas, a GObject-based plugin engine
Group:          Development/Tools/GUI Builders
Requires:       glade
Requires:       libpeas-gtk-1_0-0 = %{version}
Supplements:    (glade and %{name}-devel)
BuildArch:      noarch

%description -n glade-catalog-libpeas
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

This package provides a catalog for Glade, to allow the use the libpeas
widgets in Glade.

%package devel
Summary:        Development files for libpeas, a GObject-based plugin engine
Group:          Development/Languages/C and C++
Requires:       libpeas-1_0-0 = %{version}
Requires:       libpeas-gtk-1_0-0 = %{version}
Requires:       typelib-1_0-Peas-1_0 = %{version}
Requires:       typelib-1_0-PeasGtk-1_0 = %{version}

%description devel
libpeas is a gobject-based plugin engine, and is targetted at giving
every application the chance to assume its own extensibility.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dgtk_doc=true \
	-Ddemos=false \
%if !%{with lua51}
	-Dlua51=false \
%endif
%if %{with python2}
	-Dpython2=true \
%endif
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}-1.0 %{?no_lang_C}
%fdupes -s %{buildroot}%{_datadir}/doc/

%ldconfig_scriptlets -n libpeas-1_0-0
%ldconfig_scriptlets -n libpeas-gtk-1_0-0

%files -n libpeas-1_0-0
%license COPYING
%doc AUTHORS README
%{_libdir}/libpeas-1.0.so.*
%dir %{_libdir}/libpeas-1.0
%dir %{_libdir}/libpeas-1.0/loaders

%files -n typelib-1_0-Peas-1_0
%{_libdir}/girepository-1.0/Peas-1.0.typelib

%files -n libpeas-gtk-1_0-0
%{_libdir}/libpeas-gtk-1.0.so.*
# The icon is the default icon shown for loaded plugins without own definition.
%{_datadir}/icons/hicolor/*/actions/libpeas-plugin.*

%files -n typelib-1_0-PeasGtk-1_0
%{_libdir}/girepository-1.0/PeasGtk-1.0.typelib

%if %{with python3}
%files loader-python3
%{_libdir}/libpeas-1.0/loaders/libpython3loader.so
%endif

%if %{with lua51}
%files loader-lua51
%{_libdir}/libpeas-1.0/loaders/liblua51loader.so
%endif

%files -n glade-catalog-libpeas
%{_datadir}/glade/catalogs/libpeas-gtk.xml

%files devel
%{_datadir}/doc/libpeas-1.0
%{_datadir}/doc/libpeas-gtk-1.0
%{_includedir}/libpeas-1.0/
%{_libdir}/libpeas-1.0.so
%{_libdir}/libpeas-gtk-1.0.so
%{_libdir}/pkgconfig/libpeas-1.0.pc
%{_libdir}/pkgconfig/libpeas-gtk-1.0.pc
%{_datadir}/gir-1.0/Peas-1.0.gir
%{_datadir}/gir-1.0/PeasGtk-1.0.gir

%files lang -f %{name}-1.0.lang

%changelog
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext: allow OBS to
  shortcut through gettext-runtime-mini.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.36.0:
  + PeasExtensionSet now implements GListModel.
  + libpeas now requires GLib 2.44 or newer for GListModel.
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.34.0:
  + Resource-based plugins are sorted by module-name before loading
    to aid in reproducibility.
  + Sorting of plugins with dependencies has been altered to
    improve sort-order with more complex plugin dependency graphs.
  + Updated translations.
- Add fdupes BuildRequires and macro, remove duplicate files.
- Package sub-package glade-catalog-libpeas as noarch.
* Sat Mar 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.32.0:
  + Icon licenses have been corrected.
  + Parallel build system operation fixes.
  + Various build warnings squashed.
  + Various GIR data that should not have been exported was
    removed.
  + Use gi-docgen for documentation.
  + Updated translations.
- Drop patches fixed upstream:
  + a9d2ba590641d832dcf6b97184687b6eb424c00f.patch
  + dfc763c16c0ce66a180ccb13205f1ca9666278a8.patch
  + 2a976339f444d70f10949901a6ee2b1f8ccb24b6.patch
- Replace gtk-doc with pkgconfig(gi-docgen) BuildRequires following
  upstream changes.
* Tue Feb  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream bug fix patches:
  + a9d2ba590641d832dcf6b97184687b6eb424c00f.patch: icons: Update
    icon licenses
  + dfc763c16c0ce66a180ccb13205f1ca9666278a8.patch: icons: Correct
    icon licenses again
  + 2a976339f444d70f10949901a6ee2b1f8ccb24b6.patch: Build: add
    embedded-resources.h to libembedded_dep
- Use ldconfig_scriptlets macro for post(un) handling.
- Update our Supplements to current standard.
- Stop removing no longer exisiting la files, not present after the
  switch to meson build system.
- Stop packaging the demo files/sub-package, pass demos=false to
  meson, and add libpeas-demo Obsolets to main lib.
- Remove all traces of already disabled via bcond
  libpeas-loader-python sub-package, there is no chance we will
  package that again.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Mar 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.30.0:
  + Build system improvements.
  + Improvements when running on Windows.
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 1.28.0:
  + Do not build tests when introspection is disabled/missing
  + Updated translations.
* Sat Mar  7 2020 bjorn.lie@gmail.com
- Update to version 1.26.0:
  + Simplified i18n usage.
  + Build system fixes.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 1.25.3:
  + Fix access to peas_gettext().
  + Fix duplicate rename-to annotations.
  + Tighten symbol availability for GLib symbols.
  + Fix various tests to work with G_DISABLE_ASSERT.
  + Fix building with luajit.
  + Add peas_extension_set_new_with_properties() to aid in using
    libpeas from language bindings.
  + Fix naming of Python2 loader.
  + Remove use of undocumented -export-dynamic.
  + Fis use of PeasExtension with GInitiallyUnowned.
  + Build fixes for macOS.
  + Fixes to pkg-config files.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Jan 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Change %%bcond_without python2 to %%bcond_with python2, no longer
  build python2 support.
* Sat Jan 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add explicit gtk-doc BuildRequires, previously pulled in via
  gobject-python-common-devel.
* Mon Oct 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.1:
  + Fix missing access to peas_gettext() in public ABI.
  + Fix loading of python2 plugin loader.
  + Fix use of -export-dynamic with Clang.
  + Various macOS build fixes.
  + Fixes for libpeas-gtk pkg-config generation.
  + Add support for GInitiallyUnowned with PeasExtension.
  + Updated translations.
- Drop leftover _service and _servicedata files, package have been
  switched back to tarball releases in last unstable cycle.
* Fri Oct  4 2019 Michael Gorse <mgorse@suse.com>
- Require gettext, rather than gettext-runtime-mini.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 1.24.0:
  + Setup troubleshooting environment when running automated tests.
  + Translation updates.
* Thu Sep  5 2019 mgorse@suse.com
- Update to version 1.23.92:
  + Fix soname usage to match 1.22.x.
  + Fix typo in deprecation ignores.
  + Fix gtk_menu_popup() deprecations.
  + Fix meson build warning.
  + Translation updates.
- Soname is 1.0-0 again.
- Reinstate demo package; it is being installed again.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 1.23.90.1:
  + Ensure that programs linking against libpeas-1.0 also link
    against gobject-introspection-1.0.
  + Changes in version 1.23.90:
  + Port to meson build system, autotools has been removed.
  + Support for python3.8 in the python3 loader.
  + Reduce warning impact of GParameter deprecations on API
    consumers.
  + Fix a number of deprecations in internal API.
  + Remove use of intltool in favor of gettext.
  + Add versioning macros and hide non-public symbols.
  + Translation updates.
- Switch to meson.
- Drop intltool from BuildRequires; require gettext-runtime-mini.
- Pass libpeas-1.0 to %%find_lang.
- Python 2 loader is now named libpython2loader.so.
- Update package names: soname is now 1_0-1.
- Remove demo package: no longer installed.
* Wed Aug 28 2019 Michael Gorse <mgorse@suse.com>
- Remove libpeas-loader-python from Recommends. There is already a
  Supplements that will install it if python 2 is installed, and
  hopefully this will keep it off the LiveCD.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Jan  8 2018 zaitor@opensuse.org
- Use make_build macro.
- Avoid running fdupes across hardlink boundaries.
* Mon Jan  8 2018 tchvatal@suse.com
- Update URL to reflect current web, old was 404.
- Run spec-cleaner.
- Fix typo on parallel build command call.
- Conditionalize py2 and py3 build to allow us building of the
  one we desire based on codestream.
* Sun Sep 10 2017 dimstar@opensuse.org
- Update to version 1.22.0:
  + Updated translations.
* Fri Sep  8 2017 jengelh@inai.de
- Update description, RPM groups and old macros.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 1.21.0+git.20170807:
  + Release 1.21.0.
* Tue Jul  4 2017 zaitor@opensuse.org
- Update to version 1.21.0+git.20170609:
  + Consider all an interfaces potential properties.
  + Fix PeasEngine virtual annotations.
  + Allow extensions to be an Abstract Base Class.
  + Cache an extension type's base class and interfaces.
  + Updated translations.
- Switch to sourceservice, add gnome-common BuildRequires and pass
  autogen.sh.
- Following the above, pass --enable-gtk-doc to configure,
  explicitly build documentation, needed now that we are on a git
  checkout.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Stop passing V=1 to make, we do debugging locally.
- Drop post(un) handling of icon_theme_cache for libpeas-gtk-1_0-0,
  no longer needed as we now rely on file triggers.
* Mon Sep 19 2016 dimstar@opensuse.org
- Update to version 1.20.0:
  + Updated translations.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 1.18.0:
  + Updated translations.
* Tue Jan 26 2016 zaitor@opensuse.org
- Update to version 1.17.0:
  + Fix Python plugin loader module paths.
  + Do not add pyexecdir to Python's paths at runtime.
  + Add support for embedded C plugins.
  + Order the PeasEngine:plugin-list by dependencies.
  + Keep plugins order in PeasExtensionSet.
  + Misc bugfixes.
  + Updated translations.
* Tue Nov 24 2015 fcrozat@suse.com
- Update the list of recommended loaders:
  + Add python3 loader: most current apps are py3 by now, so
    recommending this loader makes sense (boo#956453).
* Tue Nov 24 2015 dimstar@opensuse.org
- Update the list of recommended loaders:
  + Remove seed loader: it doesn't exist anymore since 1.13.
  + Add python3 loader: most current apps are py3 by now, so
    recommending this loader makes sense (boo#956453).
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 1.16.0:
  + Updated translations.
* Thu Jun 25 2015 zaitor@opensuse.org
- Update to version 1.15.0:
  + Add g_autoptr() autocleanup support.
  + Fix Python tests on OpenBSD.
  + Fix libpeas crash on windows.
  + Simplify __all__ support in the Python plugin loader.
  + Misc bugfixes.
  + Updated translations.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 1.14.0:
  + Misc bugfixes.
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 1.13.0:
  + Removed support for Seed plugins.
  + Added support for Lua 5.1 plugins using the LGI bindings.
  + PeasEngine is now thread-safe.
  + Added support for non-global plugins loaders.
  + Load C plugins with local linkage.
  + Use Python to implement the plugin loader's logic.
  + Support Python plugins that define __all__.
  + Use Lua to implement the plugin loader's logic.
  + Prevent the accidental escaping of globals with Lua plugins.
  + Misc bugfixes.
  + Updated translations.
- Remove seed loader specific parts:
  + Drop libseed-gtk3-devel BuildRequires:
  + Remove libpease-loader-seed subpackage.
- Add LUA 5.1 loader support (conditional, currently disabled):
  + Add lua51-devel and pkgconfig(luajit) BuildRequires.
  + Add libpeas-loader-lua51 subpackage.
  + Pass --enable-lua51 to configure.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 1.12.1:
  + Dist the GResources XML of the Python plugin loaders.
- Changes from version 1.12.0:
  + Add easy python profiling support.
  + Disable GLib diagnostics in tests.
  + Fix various deprecation warning from GTK+.
  + Check return values from Python API.
  + Misc bugfixes.
  + Updated translations.
* Fri Aug  1 2014 zaitor@opensuse.org
- Update to version 1.10.1:
  + Fix initializing Python loader from Python application.
  + Prevent and warn when trying to enable multiple loaders.
  + W32: Allow shared libs to be built.
  + Misc bugfixes.
* Mon Mar 31 2014 dimstar@opensuse.org
- Update to version 1.10.0:
  + Remove support for gjs-based Javascript plugins.
  + Misc bugfixes.
* Tue Jan 28 2014 dimstar@opensuse.org
- Drop gjs loader support, following upstreams commits in git. GJS
  itself switched to using mozjs-24, which is not compatible with
  the gjs loader:
  + Drop pkgconfig(gjs-internals-1.0) BuildRequires.
  + Drop libpeas-gjs-loader subpackage.
  + Obsolete libpeas-gjs-loader from libpeas-1_0-0 instead of
    Suggesting it. This allows us to clean up eventual installs.
* Sun Jun 16 2013 zaitor@opensuse.org
- Update to version 1.9.0:
  + Misc bugfixes.
  + Updated translations.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 1.8.0:
  + Misc bugfixes.
  + Updated translations.
* Fri Mar 15 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 1.7.0:
  + Add python3 loader.
  + Updated translations.
- Add python3-devel BuildRequires to also build the python3 loader.
- Create loader-python3 subpackage.
* Sun Nov 25 2012 dimstar@opensuse.org
- Update to version 1.6.2:
  + Fix gjs single-include issues.
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 1.6.1:
  + Better SIGINT handling for python signals module.
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 1.6.0:
  + Remove the vala demo plugin
  + Add min required and max allowed version for glib and Gdk
  + Updated translations.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 1.5.0:
  + Warn if activate or deactivate are not implemented
  + Find extension construct properties also in interface
    prerequisites
  + Fix interface sorting in GJS and Seed
  + Added peas_engine_prepend_search_path
  + Added peas_plugin_info_get_external_data
  + Misc bugfixes
  + Updated translations.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 1.4.0:
  + Fix critical warning when destroying a PeasPluginManagerView.
  + Updated translations.
* Wed Mar 14 2012 vuntz@opensuse.org
- Drop libpeas-released-gjs.patch: we have a new gjs now.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh:
  those were needed for above patch only.
* Mon Feb 27 2012 vuntz@opensuse.org
- Add libpeas-released-gjs.patch: fix to build with the current
  tarball of gjs, instead of requiring some change from git. We'll
  drop the patch when we'll get a new gjs release.
- Add gnome-common BuildRequires and call to gnome-autogen.sh,
  needed for above patch.
* Sat Feb 25 2012 dimstar@opensuse.org
- Update to version 1.3.0:
  + Extensions can now implement multiple interfaces.
  + Added GSettings API to PeasPluginInfo.
  + Misc improvement and fixes.
  + Updated translations.
- Add explicit pkgconfig(gio-2.0) BuildRequires: new dependency
  upstream.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib files into their own subpackages:
  typelib-1_0-Peas-1_0 and typelib-1_0-PeasGtk-1_0
- Add typelib-1_0-Peas-1_0 and typelib-1_0-PeasGtk-1_0 Requires to
  devel subpackage.
* Wed Oct  5 2011 vuntz@opensuse.org
- Build and package the glade catalog (bnc#689575):
  + Add pkgconfig(gladeui-2.0) BuildRequires.
  + Pass --enable-glade-catalog to configure.
  + Create glade-catalog-libpeas subpackage.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 1.2.0:
  + Fix using Python plugins.
  + Misc improvement and fixes.
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 1.1.4:
  + Fix to work with PyGObject 3.
  + Do not expose the peas_extension_set_call* API to
    GObject-Introspection.
  + Disable log hooks used by PyGObject and Seed.
  + Doc updates.
  + Misc improvement and fixes.
  + Updated translations.
* Fri Sep  2 2011 vuntz@opensuse.org
- Update to version 1.1.3:
  + Do not expose the PeasExtension API using GObject-Introspection
  + Misc improvement and fixes.
- Add Url tag.
* Mon Aug 22 2011 dimstar@opensuse.org
- Update to version 1.1.2:
  + Link against pygobject 3.
  + Do not cast pointers to unsigned integers.
  + Doc updates.
  + Updated translations.
- Replace pkgconfig(pygobject-2.0) BuildRequires with
  pkgconfig(pygobject-3.0) following upstream change.
- Drop libpeas-new-gjs.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  as those were only needed for libpeas-new-gjs.patch.
* Mon Aug  8 2011 dimstar@opensuse.org
- Use versioned BuildRequires to instruct OBS to wait with a build
  instead of failing it.
* Mon Aug  1 2011 vuntz@opensuse.org
- Add libpeas-new-gjs.patch: fix build with gjs 1.29.16, which
  merges gjs-gi with gjs.
- Remove pkgconfig(gjs-gi-1.0) BuildRequires thanks to the patch.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  needed by the patch.
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 1.1.1:
  + PeasExtension has been deprecated
  + Ability to use C plugins without GObject-Introspection.
  + The plugin manager's disable plugins dialog will no longer show
    hidden plugins.
* Fri Jul  1 2011 vuntz@opensuse.org
- Split python loader in a libpeas-loader-python subpackage, with a
  Supplements on libpeas-1_0-0 and python.
- Add libpeas-loader-python and libpeas-loader-seed Recommends to
  libpeas-1_0-0, as well as a libpeas-loader-gjs Suggests: python
  and seed are likely to be used for plugins, so we want them by
  default; gjs is a bit less likely at the moment.
* Mon Jun 20 2011 dimstar@opensuse.org
- Update to version 1.1.0:
  + Add support for gjs-based Javascript extensions
  + Seed Javascript extension support improvements
  - Use the new() keyword to instantiate new Javascript
    extensions.
  - Previously used "copied arrays" have been deprecated.
  - Allow using prototypes when defining new extensions.
  + Add peas_extension_set_foreach()
  - Also deprecate the old peas_extension_set_call() method as a
    result.
  + Drop support for Gtk+ 2.
  + Updated translations.
- Add pkgconfig(gjs-internals-1.0) and pkgconfig(gjs-gi-1.0)
  BuildRequires.
- Create subpackages for the runtime loaders:
  + libpeas-loader-gjs, with a Supplements on libpeas-1_0-0 and gjs
  + libpeas-loader-seed, with a Supplements on libpeas-1_0-0 and
    seed
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 1.0.0:
  + Seed plugin loader fixes
  + Fix segfault when pygobject cannot be initialized
  + Fix tooltip display in the plugin manager
  + DOAP file update
  + Updated translations.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 0.9.0:
  + Support VOID introspection type
  + Don't use properties to store the extension instance
  + Various bug fixes
  + Fix getting and setting Seed properties
  + Privatize PeasExtensionBase, PeasExtensionClass
  + Drop IAge support for now.
  + Updated translations
- Changes from version 0.7.4:
  + Fix crash when searching a plugin in the manager.
  + Various bug fixes in tests.
  + Fix memleaks
  + Increase pygobject dependency to 2.28.0
* Thu Feb 24 2011 fcrozat@novell.com
- Update to version 0.7.3:
  + Fix bug when lazy loading fails
  + Fix C plugins that do not inherit from PeasExtensionBase
  + Fix PeasExtensionSet example in the docs
  + Don't GC plugin loaders that fail
  + Only emit notify::plugin-list when it has changed
  + Don't try to open a directory as a .plugin
  + Unref the window in the second time plugin
  + Don't add extra ref on python instance
  + Show dialog when disabling a plugin which is depended on
  + Drop PeasPluginInfo:file as it is unused
  + Add PeasPluginInfo:Hidden
  + Correctly Fix C plugins that do not inherit from
    PeasExtensionBase
  + Updated translations.
  + python: Rework refcounting to explicit extension ownership
- Changes from version 0.7.2:
  + Check that the plugin is loaded before creating an extension
  + Make PeasEngine a proper singleton
  + Move the module support check to constructor
  + Fix PeasEngine to be capable of being created multiple times
  + Fix PeasEngine:loaded-plugins to return a proper array of
    strings
  + Make peas_engine_shutdown() semi-private
  + Added the view property to PeasPluginManager
  + Add Glade catalog for libpeas-gtk
  + Show a tooltip for unavailable plugins
  + Replace plugin loader disabling with enabling
  + Add (array zero-terminated=1) annotation to API
  + Added optional engine parameter back to libpeas-gtk API
  + Allow the engine to be NULL in PeasExtensionSet
  + Allow multiple instances of PeasEngine
  + Check that the manager's view has the same engine
  + Lazy load the plugin loaders
  + Drop peas_plugin_info_get_keys()
  + Do not marshall out arguments in extension subclasses
  + Make the interface age 0.
  + Updated translations
- Changes from version 0.7.1:
  + Fix handling of g_callable_info_get_n_args()
  + Fix loading plugins with an invalid dependency
  + Fix emitting PeasExtensionSet::extension-removed
  + Fix remaining s/libpeasui/libpeas-gtk/ issues
  + Unload plugins in dispose to prevent segv
  + Don't show a plugin's description if it is NULL
  + Make the PeasEngine search-path docs make sense
  + Fix seed extensions
  + Override properties in PeasExtension subclasses
  + Allow the Icon in *.plugin to be located in the data dir
  + PeasPluginManager and View cleanup and style fixes
  + Fix implementing an interface without a VFunc invoker
  + Annotation and documentation fixes
  + Test peas_extension_call() before calling interface vfunc
  + Fix implementing interface vfuncs on 64bit
  + Emit notify::show-builtin when show-builtin is set
  + Added --pkg-export option for g-ir-scanner.
  + Plug some memory leaks
  + Updated translations
- Change pkgconfig(seed) BuildRequires to libseed-gtk3-devel as
  both gtk2 and gtk3 version share the same pkgconfig filename.
* Sun Feb 13 2011 vuntz@opensuse.org
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Dec 15 2010 dimstar@opensuse.org
- Fix -devel dependencies (lib*-1_0-0 instead of lib*-1.0-0).
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 0.7.0:
  + Add way to get a PeasExtension from a PeasExtensionSet.
  + Move the "extension-type" property to PeasExtension.
  + Convert the API using va_list to use GIArgument instead.
  + Rename libpeasui to libpeas-gtk.
  + Kill the "base module dir" property.
  + Check if the method is found in an extension call.
  + Make the various loaders define static types.
  + Make PeasExtension implement extension interfaces.
  + Fix offsets in interface handling.
  + Fixed the way seed plugin asks for an extension point.
  + Add peas_engine_append_search_path().
  + Drop application-specific naming in the info file format.
  + Add new API peas_engine_get_default().
  + Drop peas_engine_new().
  + Drop "engine" construct properties from libpeas-gtk widgets.
  + Various small fixes.
  + Build fixes.
  + Updated translations.
- Drop libpeas-fix-build-recent-gtk.patch: fixed upstream.
* Sat Sep 18 2010 vuntz@opensuse.org
- Add libpeas-fix-build-recent-gtk.patch to fix build with GTK+
  2.90.7.
* Thu Aug 26 2010 dimstar@opensuse.org
- Update to version 0.5.5:
  + Big API breaks for this release:
  - libpeasui got renamed to libpeas-gtk.
  - peas_engine_new() lost one argument.
  + Add way to get a PeasExtension from a PeasExtensionSet
  + Fix various gcc warnings
  + Updated translations.
- Use %%icon_theme_cache_post/%%icon_theme_cache_postun macros.
- Rename libpeasui-1_0-0 to libpeas-gtk-1_0-0, following the rename
  of the library.
- Don't package NEWS file, as it's empty.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 0.5.4 and cleanup for inclusion in Factory.
* Sun Jul 18 2010 dimstar@opensuse.org
- Initial package of libpeas 0.5.2
